==> ann-0.3.tar.gz: ann-0.3/include/ann_sink_log.h <==
/***************************************************************************
                          ann_sink_log.h  -  description
                             -------------------
    begin                : nie maj 4 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef __ANN_SINK_LOG_H
#define __ANN_SINK_LOG_H

#include <ann_sink.h>
#include <ann_log.h>

namespace ANN
{

  class Sink_log;

  //                //
 // class Sink_log //
//                //

  class Sink_log : public Sink
  {
  private:
    Sink_log();
    Sink_log(const Sink_log &that);

  protected:
    Log *log;

  public:
    Sink_log(Log &log_) : log(&log_) {}
    virtual ~Sink_log();

    virtual bool prepare(Size lengths, Size sizes, const char *label_in_=0,
                         const char *label_des_out_=0);
    virtual bool feed(size_t which_, const Loc &where_, const Term &in,
                      const Term *des_out);
    virtual bool update();
  };

} // namespace ANN

#endif /* __ANN_SINK_LOG_H */

==> ann-0.4.tar.gz: ann-0.4/include/ann_sink_log.h <==
/***************************************************************************
                          ann_sink_log.h  -  description
                             -------------------
    begin                : nie maj 4 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef __ANN_SINK_LOG_H
#define __ANN_SINK_LOG_H

#include <ann_sink.h>
#include <ann_log.h>

namespace ANN
{

  class Sink_log;

  //                //
 // class Sink_log //
//                //

  class Sink_log : public Sink
  {
  private:
    Sink_log();
    Sink_log(const Sink_log &that);

  protected:
    Log *log;

  public:
    Sink_log(Log &log_, const char *label_=0) : log(&log_)
    { set_label(label_); }
    virtual ~Sink_log();

    virtual bool open(Size lengths, Size sizes);
    virtual bool feed(size_t which_, const Loc &where_, const Term &in,
                      const char *label=0);
    virtual bool close();
  };

} // namespace ANN

#endif /* __ANN_SINK_LOG_H */
